.. _reference_rewrites:

Rewrites
========

This section of the documentation references all the rewrites that can be applied during the compilation of an Aesara graph

Tensor rewrites
---------------

These rewrites are implemented in the module :mod:`tensor.rewriting.basic`.

.. automodule:: aesara.tensor.rewriting.basic
   :members:

Indexing
--------

.. automodule:: aesara.tensor.rewriting.subtensor
   :members:

Shape
-----

.. automodule:: aesara.tensor.rewriting.shape
   :members:

Mathematical operations
-----------------------

.. automodule:: aesara.tensor.rewriting.math
   :members:

.. automodule:: aesara.tensor.rewriting.elemwise
   :members:

.. automodule:: aesara.tensor.rewriting.extra_ops
   :members:

.. automodule:: aesara.tensor.rewriting.special
   :members:

Random variables
----------------

.. automodule:: aesara.tensor.random.rewriting.basic
   :members:
